.. include:: ../README.rst

Content
-------

.. toctree::
    :maxdepth: 2

    usage/installation
    usage/font_installation

.. toctree::
    :maxdepth: 2
    :caption: Simple examples

    basics/1d_hist
    basics/2d_hist
    basics/1d_func

.. toctree::
    :maxdepth: 2
    :caption: Advanced examples

    advanced/model_examples
    advanced/other_advanced

.. toctree::
    :maxdepth: 2
    :caption: Utilities

    basics/variable_registry
    usage/style
    usage/utilities
    usage/plot_fitting_results

.. toctree::
    :maxdepth: 2
    :caption: Documentation

    example_gallery/index
    documentation/documentation
    documentation/statistics
